@@ -15,12 +15,12 @@ limitations under the License.
 
 """
 
+import io
 import os
 import shutil
-import io
 
 from freezer.storage import fslike
-from freezer import utils
+from freezer.utils import utils
 
 
 class LocalStorage(fslike.FsLikeStorage):
